@@ -23,6 +23,8 @@ from pprint import pprint
 
 from config import MicroblogConfig
 import microblog
+import os
+import tempfile
 import logging
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
@@ -61,15 +63,34 @@ def update(**kwargs):
         url = kwargs['url']
         shortener = kwargs['shortener']
         kwargs['interval'] = parsetime('00:05')
+    pid = os.getpid()
+    log.debug('Starting feed2mb with pid: ' + str(pid))
+#    print(configs)
+#    sys.exit()
+    if not configs[0]['pidfile']:
+	pidfile = tempfile.NamedTemporaryFile()
+    else:
+	pidfile = open(configs[0]['pidfile'], 'w+b')
 
-    log.debug('Starting feed2mb')
-    while True:
-        interval = configs[0]['interval']
-        for cf in configs:
-            the_service = microblog.service(**cf).get()
-            the_service.update()
-            log.debug('next ' + cf['service'] + ' update in: ' + str(interval) + ' seconds')
-        time.sleep(interval)
+    pidfile.write(str(pid))
+    pidfile.flush()
+#        pidfile.close()
+    log.debug('PID saved in: ' + pidfile.name)
+#    print(configs)
+#    sys.exit()
+    try:
+        while True:
+            interval = configs[0]['interval']
+            for cf in configs:
+                the_service = microblog.service(**cf).get()
+                the_service.update()
+                log.debug('next ' + cf['service'] + ' update in: ' + str(interval) + ' seconds')
+            time.sleep(interval)
+    finally:
+	pidfile.close()
+	os.remove(configs[0]['pidfile'])
 
-__version__ = '0.7.5'
+
+
+__version__ = '0.7.6'
 
