@@ -42,6 +42,10 @@ class MicroblogConfig(ConfigParser):
                 config['items'] = self.getint(section,"items")
             except NoOptionError:
                 config['items'] = 5
+	    try:
+                config['pidfile'] = self.get("global","pidfile").strip()
+            except NoOptionError:
+		config['pidfile'] = None	
             try:
                 config['interval'] = parsetime(self.get("global","interval").strip())
             except:
